package benten.twa.cat.core;

import java.util.ArrayList;
import java.util.List;

import junit.framework.TestCase;
import benten.cat.tm.core.BentenTmSearchResult;

public class BentenTmUtilTest extends TestCase {

	public void testAdjustForUntrim() {
		assertEquals("前後に何も無し", "hello", BentenTmUtil.adjustForUntrim("hello", "hello", "hello"));
		assertEquals("前後に何も無し", "こんにちは", BentenTmUtil.adjustForUntrim("hello", "hello", "こんにちは"));
		assertEquals("後方に半角 1 つ", "こんにちは", BentenTmUtil.adjustForUntrim("hello", "hello ", "こんにちは "));
		assertEquals("後方に半角 2 つ", "こんにちは", BentenTmUtil.adjustForUntrim("hello", "hello  ", "こんにちは  "));
		assertEquals("前方に半角 1 つ", "こんにちは", BentenTmUtil.adjustForUntrim("hello", " hello", " こんにちは"));
		assertEquals("前方に半角 2 つ", "こんにちは", BentenTmUtil.adjustForUntrim("hello", "  hello", "  こんにちは"));

		assertEquals("後方に半角 1 つ", "こんにちは ", BentenTmUtil.adjustForUntrim("hello ", "hello", "こんにちは"));
		assertEquals("後方に半角 2 つ", "こんにちは  ", BentenTmUtil.adjustForUntrim("hello  ", "hello", "こんにちは"));
		assertEquals("前方に半角 1 つ", " こんにちは", BentenTmUtil.adjustForUntrim(" hello", "hello", "こんにちは"));
		assertEquals("前方に半角 2 つ", "  こんにちは", BentenTmUtil.adjustForUntrim("  hello", "hello:", "こんにちは"));

		assertEquals("バリエーション", "こんにちは ", BentenTmUtil.adjustForUntrim("hello ", "hello ", "こんにちは "));
		assertEquals("バリエーション", "こんにちは  ", BentenTmUtil.adjustForUntrim("hello  ", "hello ", "こんにちは "));
		assertEquals("バリエーション", " こんにちは", BentenTmUtil.adjustForUntrim(" hello", "hello ", "こんにちは "));
		assertEquals("バリエーション", "  こんにちは", BentenTmUtil.adjustForUntrim("  hello", "hello ", "こんにちは"));

		assertEquals("トリム", "こんにちは", BentenTmUtil.adjustForUntrim("hello", "(hello)", "(こんにちは)"));
		assertEquals("トリム", "こんにちは", BentenTmUtil.adjustForUntrim("hello", "--- hello ---", "--- こんにちは ---"));
		assertEquals("トリム", "こんにちは", BentenTmUtil.adjustForUntrim("hello", "hello&nbsp;", "こんにちは&nbsp;"));

		assertEquals("強制トリム", "こんにちは", BentenTmUtil.adjustForUntrim("hello", "hello:", "こんにちは:"));
		assertEquals("強制トリム", "こんにちは", BentenTmUtil.adjustForUntrim("hello", "hello.", "こんにちは。"));
		assertEquals("強制トリム", "こんにちは。", BentenTmUtil.adjustForUntrim("hello.", "hello", "こんにちは"));
		assertEquals("強制トリム", "こんにちは!", BentenTmUtil.adjustForUntrim("hello!", "hello", "こんにちは"));
	}

	public void testSearchExactMatch01() throws Exception {
		final List<BentenTmSearchResult> matchList = new ArrayList<BentenTmSearchResult>();
		{
			assertEquals("1 件もない", null, BentenTmUtil.searchExactMatch(matchList, "hello"));
		}

		{
			final BentenTmSearchResult res1 = new BentenTmSearchResult();
			matchList.add(res1);
			res1.setSource("hello");
			res1.setTarget("こんにちは");
			// match-quality は無視!
			assertEquals("1 件のみヒット", "こんにちは", BentenTmUtil.searchExactMatch(matchList, "hello"));
		}

		{
			assertEquals("1 件のみヒット", "こんにちは ", BentenTmUtil.searchExactMatch(matchList, "hello "));
		}

		{
			final BentenTmSearchResult res1 = new BentenTmSearchResult();
			matchList.add(res1);
			res1.setSource("hello");
			res1.setTarget("にいはお");
			assertEquals("2 件あたり、それらがおのおの異なる", null, BentenTmUtil.searchExactMatch(matchList, "hello"));
		}
	}

	public void testSearchExactMatch02() throws Exception {
		final List<BentenTmSearchResult> matchList = new ArrayList<BentenTmSearchResult>();
		{
			assertEquals("1 件もない", null, BentenTmUtil.searchExactMatch(matchList, "hello"));
		}

		{
			final BentenTmSearchResult res1 = new BentenTmSearchResult();
			matchList.add(res1);
			res1.setSource("hello");
			res1.setTarget("こんにちは");
			// match-quality は無視!
			assertEquals("1 件のみヒット", "こんにちは", BentenTmUtil.searchExactMatch(matchList, "hello"));
		}

		{
			final BentenTmSearchResult res1 = new BentenTmSearchResult();
			matchList.add(res1);
			res1.setSource("hello ");
			res1.setTarget("こんにちは ");
			assertEquals("2 件あたり、それらが一致する", "こんにちは", BentenTmUtil.searchExactMatch(matchList, "hello"));
		}

		{
			final BentenTmSearchResult res1 = new BentenTmSearchResult();
			matchList.add(res1);
			res1.setSource(" hello");
			res1.setTarget(" こんにちは");
			assertEquals("3 件あたり、それらが一致する", " こんにちは  ", BentenTmUtil.searchExactMatch(matchList, " hello  "));
		}
	}
}
